# Terms of Service

## Welcome

VulnerableCode.io provides a data service that allows users to access information about security vulnerabilities via the web site or API. These Terms of Service govern your access to and use of https://public.vulnerablecode.io (our “Site”) and our products and services (collectively, the "Service"), and any information appearing on the Service. Any reference to “you” or “your” means you as a user of the Service, any reference to “we”, “us”, “our” or “nexB” is to nexB Inc., a California USA corporation.

By using the Service you agree and consent to these Terms of Service including terms that limit our liability or affect your legal rights, any referenced and incorporated guidelines and policies, including our Code of Conduct, the terms of our Privacy Policy, and any additional terms specific to your particular use of the Service which become part of your agreement with us (collectively, the “Terms”). If you are using the Service on behalf of a business, you represent to us that you have authority to bind that business or entity to these Terms, and that business accepts these Terms.

The data provided by or obtained from the Service is licensed under the Creative Commons Attribution-ShareAlike 4.0 International Public License - http://creativecommons.org/licenses/by-sa/4.0/. If you share the data with any third party you must include the following attribution notice:

VulnerableCode data by nexB Inc. is licensed under the Creative Commons Attribution-ShareAlike 4.0 International Public License.

## Restrictions on Your Use of the Service

You agree that you may not:

- Use the Service in any way that breaches any applicable local, national, or international law or regulation.
- Use the Service in any way which could infringe the rights or interests of nexB or any third party.
- Use the Service for any illegal activity or output, or in any way that exposes nexB, you, or other users of the Service to harm or liability.
- Engage in any activity that could damage, overload, harm or impede the normal functioning of the Service.
- Gain unauthorized access to our Site, the server on which our Site is stored or any server, computer or database connected to our Site.
- Attack, or attempt to attack our Site via a denial-of-service attack or a distributed denial-of service attack.
- Allow, enable or assist any other person or entity to violate any provisions of these Terms.

## Registration

The Service may be used only by persons who are at least of the age of majority and can form legally binding contracts under applicable law. The Service may not be used by persons in jurisdictions where access to or use of it may be illegal or prohibited.

The Service offers certain functionality that may require the creation of a personal account (e.g. to use the API). You promise to provide us with accurate, complete and updated registration information. You are exclusively responsible for generating unique and complex credentials, safeguarding them, and for any activities or actions taken on the Service using such credentials. You may not transfer your account to anyone else.

We do not collect, share nor sell personal data. Data handling is minimized to legal, regulatory, and technical requirements. We are not a data processor. Our Privacy Policy is at https://nexb.com/privacy/.

## Changes in Service

The Service provided by nexB is constantly evolving, and the form and nature of the Service that nexB provides may change from time to time without prior notice to you. Any changes to the Service, including the release of new features, are subject to the Terms then in effect. In addition, we may stop (permanently or temporarily) providing the Service (or any features within the Service) without providing prior notice. We also retain the right to create and apply limits on your use of the Service including API access, at our sole discretion, at any time without prior notice to you.

## Disclaimers

Your access to and use of the service is at your own risk. you understand and agree that the Service is provided to you on an "as is" basis, without any representations, warranties or conditions of any kind, whether express or implied, and including without limitation implied representations, warranties or conditions of title, non-infringement, merchantability, fitness for a particular purpose, performance, durability, availability, timeliness, accuracy, or completeness, all of which are hereby disclaimed by nexB.

We do not warrant or guarantee that the Service is accurate, reliable or correct; that the Service will meet your requirements; that the Service will be available at any particular time or location, uninterrupted, error-free, without defect or secure; or that any defects or errors will be corrected.

Our Service may contain links to third-party websites or other resources. (“Third Party Content”). nexB does not control the Third Party Content and is not responsible for the Third Party Content, including the accuracy, availability, completeness, reliability, security, substance or timeliness of the Third Party Content. To the extent that the Service makes available any Third Party Content that is made available under an open source license, you are responsible for ensuring that you comply with all such license terms if you use such Third Party Content. Your use of the Third Party Content is at your own risk and subject to the terms and conditions published by the owners of the Third Party Content.

## Limitation of Liability

To the maximum extent permitted under applicable law, the Service is provided on an “as is” and “as available” basis, without any representations, warranties or conditions of any kind, whether express or implied, and including without limitation implied representations, warranties or conditions of title, non-infringement, merchantability, fitness for a particular purpose, performance, durability, availability, timeliness, accuracy, or completeness, all of which are hereby disclaimed by nexB.

To the fullest extent permitted by applicable law, (a) nexB will not be liable to you or any third party for any indirect, incidental, consequential, special, exemplary or punitive damages of any kind, under any contract, tort (including negligence), strict liability or other theory, including damages for loss of profits, use or data, loss of other intangibles, even if advised in advance of the possibility of such damages or losses; (b) without limiting the foregoing, nexB will not be liable to you or any third party for damages of any kind resulting from your use of or inability to use the Service; and (c) your sole and exclusive remedy for dissatisfaction with the Service is to stop using the Service.

## About These Terms

Please note that we may update and amend these Terms from time to time and any changes will be posted on the Site. By continuing to access the Service after any changes become effective, you agree to be bound by the revised Terms.

The failure of nexB to enforce any right or provision of these Terms will not be deemed a waiver of such right or provision. In the event that any provision of these Terms is held to be invalid or unenforceable, the remaining provisions of these Terms will remain in full force and effect.

These Terms will be governed by laws of the State of California, without respect to its conflict of laws principles. The sole jurisdiction and venue for any claim arising from these Terms shall be the state and federal courts located in Santa Clara County, California, USA.

If you have any doubts as to whether your use of the Service complies with these Terms or have a concern with any aspect of the Site or the Service, please contact us.